==> beautiful_soup_dart-0.0.1.tar.gz: lib/src/bs_soup.dart <==
import 'package:html/parser.dart';

import 'shared.dart';

/// {@template bs_soup}
/// Beautiful Soup is a library for pulling data out of HTML files.
/// It provides ways of navigating, searching, and modifying the parse tree.
/// It commonly saves programmers hours or days of work.
///
/// How it should be used?
///
/// **1.** parse a document
///
/// ```
/// BeautifulSoup bs = BeautifulSoup(html_doc_string);
/// BeautifulSoup bs = BeautifulSoup.fragment(html_doc_string); // if it is just a part of html
/// ```
///
/// **2.** navigate quickly to any element
///
/// ```
/// Bs4Element bs4 = bs.body.p; // quickly with tags
/// Bs4Element bs4 = bs.find('p', attrs: {'class': 'story'}); // with query func
/// ```
///
/// **3.** perform any other actions
///
/// ```
/// bs4.name; // get tag name
/// bs4.string; // get text
/// bs4.toString(); // get String representation of this element, same as outerHtml
/// bs4.innerHtml; // get html elements inside the element
/// bs4.className; // get class attribute value
/// bs4['class']; // get class attribute value
/// bs4['class'] = 'board'; // change class attribute value to 'board'
/// bs4.children; // get all element's children elements
/// bs4.replaceWith(otherBs4Element); // replace with other element
/// ```
///
/// and many more!
/// {@endtemplate}
class BeautifulSoup extends Shared {
  /// {@macro bs_soup}
  BeautifulSoup(String html_doc) {
    doc = parse(html_doc);
  }

  /// {@macro bs_soup}
  BeautifulSoup.fragment(String html_doc) {
    doc = parseFragment(html_doc);
  }

  @override
  String toString() => doc.outerHtml;
}

==> beautiful_soup_dart-0.1.0.tar.gz: lib/src/bs_soup.dart <==
import 'package:html/parser.dart';

import 'shared.dart';

/// {@template bs_soup}
/// Beautiful Soup is a library for pulling data out of HTML files.
/// It provides ways of navigating, searching, and modifying the parse tree.
/// It commonly saves programmers hours or days of work.
///
/// How it should be used? 3 easy steps.
///
/// **1.** parse a document
///
/// ```
/// BeautifulSoup bs = BeautifulSoup(html_doc_string);
/// BeautifulSoup bs = BeautifulSoup.fragment(html_doc_string); // if it is just a part of html
/// ```
///
/// **2.** navigate quickly to any element
///
/// ```
/// Bs4Element bs4 = bs.body.p; // quickly with tags
/// Bs4Element bs4 = bs.find('p', attrs: {'class': 'story'}); // with query func
/// Bs4Element bs4 = bs.find('', customSelector: '#link1'); // find with custom CSS selector (other parameters are ignored)
/// ```
///
/// **3.** perform any actions
///
/// ```
/// bs4.name; // get tag name
/// bs4.string; // get text
/// bs4.toString(); // get String representation of this element, same as outerHtml
/// bs4.innerHtml; // get html elements inside the element
/// bs4.className; // get class attribute value
/// bs4['class']; // get class attribute value
/// bs4['class'] = 'board'; // change class attribute value to 'board'
/// bs4.children; // get all element's children elements
/// bs4.replaceWith(otherBs4Element); // replace with other element
/// ```
///
/// and many more!
/// {@endtemplate}
class BeautifulSoup extends Shared {
  /// {@macro bs_soup}
  BeautifulSoup(String html_doc) {
    doc = parse(html_doc);
  }

  /// {@macro bs_soup}
  BeautifulSoup.fragment(String html_doc) {
    doc = parseFragment(html_doc);
  }

  @override
  String toString() => doc.outerHtml;
}
